/*
 * Copyright (C) 2012-2021 Japan Smartphone Security Association
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jssec.android.https.imagesearch;

import android.os.AsyncTask;

import java.io.BufferedInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.net.ProtocolException;
import java.net.MalformedURLException;
import java.net.HttpURLConnection;
import java.net.URL;

public abstract class HttpImageSearch extends AsyncTask<String, Void, Object> {

    @Override
    protected Object doInBackground(String... params) {
        HttpURLConnection con;
        byte[] responseArray = null;
        try {
            // --------------------------------------------------------
            // 通信：画像を取得する
            // --------------------------------------------------------
            // ★ポイント1★ 送信データにセンシティブな情報を含めない
            // 画像URL（image_url をチェックして）送信する…サンプルにつき省略
            String image_url = "http://www.jssec.org/common/images/main_visual_local.jpg";
            con = connectUrl(image_url);
            checkResponse(con);

            // ★ポイント2★ 受信データが攻撃者からの送信データである場合を想定する
            // サンプルにつき検索結果が攻撃者からのデータである場合の処理は省略
            responseArray = getByteArray(con);
            if (responseArray == null) {
                return null;
            }
        } catch (IOException e) {
            // 例外処理は省略
        }
        return responseArray;
    }

    private HttpURLConnection connectUrl(String strUrl) {
        HttpURLConnection con = null;
        try {
            URL url = new URL(strUrl);
            con = (HttpURLConnection) url.openConnection();
            con.setRequestMethod("GET");
            con.connect();
        } catch (ProtocolException e) {
            // 例外処理は省略
        } catch (MalformedURLException e) {
            // 例外処理は省略
        } catch (IOException e) {
            // 例外処理は省略
        }
        return con;
    }

    private byte[] getByteArray(HttpURLConnection con) {
        byte[] buff = new byte[1024];
        byte[] result = null;
        BufferedInputStream inputStream = null;
        ByteArrayOutputStream responseArray = null;
        int length;

        try {
            inputStream = new BufferedInputStream(con.getInputStream());
            responseArray = new ByteArrayOutputStream();

            while ((length = inputStream.read(buff)) != -1) {
                if (length > 0) {
                    responseArray.write(buff, 0, length);
                }
            }
            result = responseArray.toByteArray();
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            if (inputStream != null) {
                try {
                    inputStream.close();
                } catch (IOException e) {
                    // 例外処理は省略
                }
            }
            if (responseArray != null) {
                try {
                    responseArray.close();
                } catch (IOException e) {
                    // 例外処理は省略
                }
            }
        }
        return result;
    }

    private void checkResponse(HttpURLConnection con) throws IOException {
        int statusCode = con.getResponseCode();
        if (HttpURLConnection.HTTP_OK != statusCode) {
            throw new IOException("HttpStatus: " + statusCode);
        }
    }
}
